@@ -4,15 +4,17 @@ fi
 
 export MACOSX_DEPLOYMENT_TARGET=${MACOSX_DEPLOYMENT_TARGET:-10.9}
 
+# Some project require a new SDK version even though they can target older versions
 if [ -f ${CI_SUPPORT}/${CONFIG}.yaml ]; then
-   export WITH_LATEST_OSX_SDK=$(cat ${CI_SUPPORT}/${CONFIG}.yaml | shyaml get-value WITH_LATEST_OSX_SDK.0 0)
+    export MACOSX_SDK_VERSION=$(cat ${CI_SUPPORT}/${CONFIG}.yaml | shyaml get-value MACOSX_SDK_VERSION.0 0)
+    export WITH_LATEST_OSX_SDK=$(cat ${CI_SUPPORT}/${CONFIG}.yaml | shyaml get-value WITH_LATEST_OSX_SDK.0 0)
+    if [[ "${WITH_LATEST_OSX_SDK}" != "0" ]]; then
+        echo "Setting WITH_LATEST_OSX_SDK is removed. Use MACOSX_SDK_VERSION to specify an explicit version for the SDK."
+        export MACOSX_SDK_VERSION=10.15
+    fi
 fi
 
-if [[ "$WITH_LATEST_OSX_SDK" == "1" ]]; then
-    # Typically, we want to build with the latest SDK, even though the deployment target may be older.
-    # See: https://developer.apple.com/library/archive/documentation/DeveloperTools/Conceptual/cross_development/Configuring/configuring.html#//apple_ref/doc/uid/10000163i-CH1-SW1
-    export MACOSX_SDK_VERSION=10.15
-else
+if [[ "${MACOSX_SDK_VERSION:-0}" == "0" ]]; then
     export MACOSX_SDK_VERSION=$MACOSX_DEPLOYMENT_TARGET
 fi
 
